#[non_exhaustive]pub enum Error {
Show 20 variants
EofWhileParsingList,
EofWhileParsingObject,
EofWhileParsingString,
EofWhileParsingNumber,
EofWhileParsingValue,
ExpectedColon,
ExpectedListCommaOrEnd,
ExpectedObjectCommaOrEnd,
ExpectedSomeIdent,
ExpectedSomeValue,
InvalidNumber,
InvalidType,
InvalidUnicodeCodePoint,
KeyMustBeAString,
TrailingCharacters,
TrailingComma,
CustomError,
InvalidEscape,
ControlCharacterWhileParsingString,
CustomErrorWithMessage(String),
}Expand description
This type represents all possible errors that can occur when deserializing JSON data
Variants (Non-exhaustive)
This enum is marked as non-exhaustive
EofWhileParsingList
EOF while parsing a list.
EofWhileParsingObject
EOF while parsing an object.
EofWhileParsingString
EOF while parsing a string.
EofWhileParsingNumber
EOF while parsing a JSON number.
EofWhileParsingValue
EOF while parsing a JSON value.
ExpectedColon
Expected this character to be a ':'.
ExpectedListCommaOrEnd
Expected this character to be either a ',' or a ']'.
ExpectedObjectCommaOrEnd
Expected this character to be either a ',' or a '}'.
ExpectedSomeIdent
Expected to parse either a true, false, or a null.
ExpectedSomeValue
Expected this character to start a JSON value.
InvalidNumber
Invalid number.
InvalidType
Invalid type
InvalidUnicodeCodePoint
Invalid unicode code point.
KeyMustBeAString
Object key is not a string.
TrailingCharacters
JSON has non-whitespace trailing characters after the value.
TrailingComma
JSON has a comma after the last value in an array or map.
CustomError
Error with a custom message that we had to discard.
InvalidEscape
Invalid escape
ControlCharacterWhileParsingString
Control character while parsing string
CustomErrorWithMessage(String)
Error with a custom message that was preserved.